==> plugin.audio.vrt.radio-0.1.3.zip: plugin.audio.vrt.radio/README.md <==
[![GitHub release](https://img.shields.io/github/release/add-ons/plugin.audio.vrt.radio.svg)](https://github.com/add-ons/plugin.audio.vrt.radio/releases)
[!![CI](https://github.com/add-ons/plugin.audio.vrt.radio/workflows/CI/badge.svg)](https://github.com/add-ons/plugin.audio.vrt.radio/actions?query=workflow:CI)
[![License: GPLv3](https://img.shields.io/badge/License-GPLv3-yellow.svg)](https://opensource.org/licenses/GPLv3)
[![Contributors](https://img.shields.io/github/contributors/add-ons/plugin.audio.vrt.radio.svg)](https://github.com/add-ons/plugin.audio.vrt.radio/graphs/contributors)

# VRT Radio Kodi addon
**plugin.audio.vrt.radio** is a [Kodi](https://kodi.tv/) add-on for listening to all VRT radio streams.

## Installing
In Kodi, simply search for `VRT Radio`, and install the add-on.

Alternatively, you can download a ZIP archive from the [GitHub releases](https://github.com/add-ons/plugin.audio.vrt.radio/releases)
and install it directly in Kodi using the **Install via Zip** option.

## Reporting issues
You can report issues at [our GitHub project](https://github.com/add-ons/plugin.audio.vrt.radio).

## Releases

### v0.1.3 (2020-06-17)
- Small fix to IPTV Manager support

### v0.1.2 (2020-06-02)
- Switch from MP3 to AAC by default
- Added channel Radio 2 Bene Bene
- Added channel StuBru Hooray
- Added channel StuBru Bruut
- Added support for IPTV Manager

### v0.1.1 (2020-04-12)
- Added channel Radio 1 Classics
- Added channel StuBru #ikluisterbelgisch
- Added channel MNM Back to the 90's & 00's
- Removed channel Sporza

### v0.1.0 (2019-05-01)
- Initial working release

==> plugin.audio.vrt.radio-0.1.4.zip: plugin.audio.vrt.radio/README.md <==
[![GitHub release](https://img.shields.io/github/release/add-ons/plugin.audio.vrt.radio.svg)](https://github.com/add-ons/plugin.audio.vrt.radio/releases)
[!![CI](https://github.com/add-ons/plugin.audio.vrt.radio/workflows/CI/badge.svg)](https://github.com/add-ons/plugin.audio.vrt.radio/actions?query=workflow:CI)
[![License: GPLv3](https://img.shields.io/badge/License-GPLv3-yellow.svg)](https://opensource.org/licenses/GPLv3)
[![Contributors](https://img.shields.io/github/contributors/add-ons/plugin.audio.vrt.radio.svg)](https://github.com/add-ons/plugin.audio.vrt.radio/graphs/contributors)

# VRT Radio Kodi addon
**plugin.audio.vrt.radio** is a [Kodi](https://kodi.tv/) add-on for listening to all VRT radio streams.

## Installing
In Kodi, simply search for `VRT Radio`, and install the add-on.

Alternatively, you can download a ZIP archive from the [GitHub releases](https://github.com/add-ons/plugin.audio.vrt.radio/releases)
and install it directly in Kodi using the **Install via Zip** option.

## Reporting issues
You can report issues at [our GitHub project](https://github.com/add-ons/plugin.audio.vrt.radio).

## Releases

### v0.1.4 (2020-12-19)
- Add Dutch translation
- Add additional channels
- Improve channel logo's and fanart
- Release for Leia and Matrix

### v0.1.3 (2020-06-17)
- Small fix to IPTV Manager support

### v0.1.2 (2020-06-02)
- Switch from MP3 to AAC by default
- Added channel Radio 2 Bene Bene
- Added channel StuBru Hooray
- Added channel StuBru Bruut
- Added support for IPTV Manager

### v0.1.1 (2020-04-12)
- Added channel Radio 1 Classics
- Added channel StuBru #ikluisterbelgisch
- Added channel MNM Back to the 90's & 00's
- Removed channel Sporza

### v0.1.0 (2019-05-01)
- Initial working release
